@@ -1,51 +1,32 @@
-# webdriver manager
-# web element
-from je_web_runner.je_web_runner.element.web_element_wrapper import web_element_wrapper
-# webdriver wrapper
-from je_web_runner.je_web_runner.manager.webrunner_manager import get_webdriver_manager
-# desired_capabilities
-from je_web_runner.je_web_runner.utils.selenium_utils_wrapper.desired_capabilities.desired_capabilities import \
-    get_desired_capabilities
-from je_web_runner.je_web_runner.utils.selenium_utils_wrapper.desired_capabilities.desired_capabilities import \
-    get_desired_capabilities_keys
-# Keys
-from je_web_runner.je_web_runner.utils.selenium_utils_wrapper.keys.selenium_keys import Keys
-from je_web_runner.je_web_runner.webdriver.webdriver_with_options import set_webdriver_options_argument
-from je_web_runner.je_web_runner.webdriver.webdriver_wrapper import webdriver_wrapper
-# selenium utils
+from je_web_runner.element.web_element_wrapper import web_element_wrapper
+from je_web_runner.webdriver.webdriver_wrapper import webdriver_wrapper_instance
+from je_web_runner.manager.webrunner_manager import get_webdriver_manager
+from je_web_runner.webdriver.webdriver_with_options import set_webdriver_options_argument
+from je_web_runner.utils.selenium_utils_wrapper.desired_capabilities.desired_capabilities import \
+    get_desired_capabilities_keys, get_desired_capabilities
+from je_web_runner.utils.selenium_utils_wrapper.keys.selenium_keys import Keys
 from je_web_runner.utils.executor.action_executor import add_command_to_executor
-# utils
 from je_web_runner.utils.executor.action_executor import execute_action
 from je_web_runner.utils.executor.action_executor import execute_files
 from je_web_runner.utils.executor.action_executor import executor
 from je_web_runner.utils.file_process.get_dir_file_list import get_dir_files_as_list
-# generate html
 from je_web_runner.utils.generate_report.generate_html_report import generate_html
 from je_web_runner.utils.generate_report.generate_html_report import generate_html_report
-# json
 from je_web_runner.utils.generate_report.generate_json_report import generate_json
 from je_web_runner.utils.generate_report.generate_json_report import generate_json_report
 from je_web_runner.utils.json.json_file.json_file import read_action_json
-# xml
 from je_web_runner.utils.generate_report.generate_xml_report import generate_xml
 from je_web_runner.utils.generate_report.generate_xml_report import generate_xml_report
-# server
 from je_web_runner.utils.socket_server.web_runner_socket_server import start_web_runner_socket_server
-# test object
 from je_web_runner.utils.test_object.test_object_class import TestObject
 from je_web_runner.utils.test_object.test_object_class import create_test_object
 from je_web_runner.utils.test_object.test_object_class import get_test_object_type_list
-# test record
 from je_web_runner.utils.test_record.test_record_class import test_record_instance
-# Callback
 from je_web_runner.utils.callback.callback_function_executor import callback_executor
-# Project
 from je_web_runner.utils.project.create_project_structure import create_project_dir
-# Scheduler
-from je_web_runner.utils.scheduler.extend_apscheduler import SchedulerManager
 __all__ = [
-    "web_element_wrapper", "set_webdriver_options_argument", "SchedulerManager",
-    "webdriver_wrapper", "get_webdriver_manager",
+    "web_element_wrapper", "set_webdriver_options_argument",
+    "webdriver_wrapper_instance", "get_webdriver_manager",
     "get_desired_capabilities", "get_desired_capabilities_keys", "add_command_to_executor",
     "execute_action", "execute_files", "executor",
     "generate_html", "generate_html_report",
